"""
$RCSfile: TestCVSFile.py,v $
Unit tests for CVSFile product

Author: <a href="mailto:cstrong@arielpartners.com">Craeg Strong</a>
Release: 1.0
"""

__cvstag__  = '$Name:  $'[6:-2]
__date__    = '$Date: 2003/04/19 05:08:35 $'[6:-2]
__version__ = '$Revision: 1.5 $'[10:-2]

import os, os.path, sys, tempfile
if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

# Load fixture
from Testing import ZopeTestCase

from Products.CVSFile.OSUtils import command_separator, runCommand, \
     canonicalizeDir
from Products.CVSFile.SandboxInfo import SandboxInfo
import Products.CVSFile.CVSSandboxRegistry as registry
from Products.CVSFile import CVSFile

tmpDirectory = "/tmp"
if sys.platform == 'win32':
    tmpDirectory = "c:/tmp" # use forward slash b/c backslash is special char

ZopeTestCase.installProduct('ExternalFile')
ZopeTestCase.installProduct('CVSFile')

class CVSFileTestCase(ZopeTestCase.ZopeTestCase):

    def afterSetUp(self):

        self._testModule = 'cvsTest'
        self._testFile   = 'testfile.txt'

        cvsroot = os.environ.get('CVSROOT', None)
        if not cvsroot:
            raise EnvironmentError, "You must have CVSROOT defined to run these tests"

        self.basedir = os.path.normpath(os.path.join(tmpDirectory, 'testSandbox'))
        self.createTestModule()
        self._si = SandboxInfo("test1", canonicalizeDir(self.basedir), cvsroot)
        self._reg = registry.addInstance(self.folder,
                                         "qa", "QA Sandboxes",
                                         "These are the sandboxes for testing",
                                         "test1", canonicalizeDir(self.basedir),
                                         cvsroot)
    def createTestModule(self):
        print """
        Make sure to have your CVS administrator remove the
        %s module from the CVS repository after running these
        tests
        """ % self._testModule
        dirname  = os.path.join(self.basedir, self._testModule)
        filename = os.path.join(dirname, self._testFile)
        os.makedirs(dirname)
        touchfile = open(filename, 'wb') # create zero-length file
        touchfile.write("this is a test file")
        touchfile.close()
        command = "cd %s %s cvs import -m testing %s ArielPartners start" % (dirname,
                                                                             command_separator,
                                                                             self._testModule)
        output = runCommand(command)
        print output
        os.remove(filename)
        os.rmdir(dirname)

    def createTestSandbox(self):
        try:
            os.makedirs(self._si.basedir)
        except:
            pass # already there? that's fine
        output = self._reg.checkoutSandbox(self._testModule, '', self._si)
        print output

    def test_01(self):
        "basic no-change CVS update test"

        self.createTestSandbox()
        
        ef = CVSFile.addInstance(self.folder, 'ascii', 'Ascii File','',
                                 os.path.join(self._testModule, self._testFile))
        output = ef.updateFile(self._si, '')
        print output

# TBD: make this more robust, add more tests
# Right now, this is not idempotent :-(

    ################################################################
    # Test Runner Setup
    ################################################################

if __name__ == '__main__':
    framework(descriptions=1, verbosity=2) # 0=quiet 1=default 2=verbose
else:
    # While framework.py provides its own test_suite() 
    # method the testrunner utility does not.
    import unittest
    def test_suite():
        suite = unittest.TestSuite()
        suite.addTest(unittest.makeSuite(CVSFileTestCase))
        return suite
